@@ -8,8 +8,6 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
     return {
         isCordova => \0,
 
-        roles => [],
-
         api => {
             signin          => undef,    # $api{'Auth/signin'},
             signout         => undef,    # $api{'Auth/signout'},
@@ -20,8 +18,8 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
 
         # MATERIAL THEME
         theme => {
-            accent   => undef,
-            base     => undef,
+            accent   => 'grey',
+            base     => 'blue-grey',
             darkMode => \0
         },
 
@@ -136,21 +134,13 @@ JS
 JS
 
         checkSession => func ['session'], <<'JS',
+            session.hasRole = function (role) {
+                if (!this.is_authenticated) return 0;
 
-            // compare roles
-            if (session.is_authenticated && !session.is_root) {
-                if (this.roles && this.roles.length) {
-                    session.is_authenticated = false;
+                if (this.is_root) return 1;
 
-                    for (var role of this.roles) {
-                        if (session.permissions[role]) {
-                            session.is_authenticated = true;
-
-                            break;
-                        }
-                    }
-                }
-            }
+                return this.permissions[role] ? 1 : 0;
+            };
 
             if (!session.locale) session.locale = localStorage.locale || session.default_locale;
 
